==> ACE+TAO-6.3.3.tar.bz2: ACE_wrappers/TAO/TAO_IDL/be_include/be_visitor_any_extracted_type_decl.h <==
/* -*- c++ -*- */
//=============================================================================
/**
 *  @file    be_visitor_any_extracted_type_decl.h
 *
 *  Encapsulation of rules for declaring variables
 *  for Any extraction
 *
 *  @author Jeff Parsons
 */
//=============================================================================

#ifndef BE_VISITOR_ANY_EXTRACTED_TYPE_DECL_H
#define BE_VISITOR_ANY_EXTRACTED_TYPE_DECL_H

#include "be_visitor_decl.h"

class TAO_OutStream;

/**
 * @class be_visitor_any_extracted_type_decl
 *
 * @brief be_visitor_any_extracted_type_decl
 *
 * Contains overloaded methods that generate declarations of
 * CORBA typenames for Any extraction
 */
class be_visitor_any_extracted_type_decl : public be_visitor_decl
{
public:
  be_visitor_any_extracted_type_decl (be_visitor_context *ctx);
  virtual ~be_visitor_any_extracted_type_decl (void);

  virtual int visit_array (be_array *);
  virtual int visit_component (be_component *);
  virtual int visit_enum (be_enum *);
  virtual int visit_eventtype (be_eventtype *);
  virtual int visit_home (be_home *);
  virtual int visit_interface (be_interface *);
  virtual int visit_predefined_type (be_predefined_type *);
  virtual int visit_sequence (be_sequence *);
  virtual int visit_string (be_string *);
  virtual int visit_structure (be_structure *);
  virtual int visit_typedef (be_typedef *);
  virtual int visit_union (be_union *);
  virtual int visit_valuebox (be_valuebox *);
  virtual int visit_valuetype (be_valuetype *);

protected:
  const char * var_name_;
  const char * tmp_name_;
};

#endif /* BE_VISITOR_ANY_EXTRACTED_TYPE_DECL_H */

==> ACE+TAO-8.0.0.tar.bz2: ACE_wrappers/TAO/TAO_IDL/be_include/be_visitor_any_extracted_type_decl.h <==
/* -*- c++ -*- */
//=============================================================================
/**
 *  @file    be_visitor_any_extracted_type_decl.h
 *
 *  Encapsulation of rules for declaring variables
 *  for Any extraction
 *
 *  @author Jeff Parsons
 */
//=============================================================================

#ifndef BE_VISITOR_ANY_EXTRACTED_TYPE_DECL_H
#define BE_VISITOR_ANY_EXTRACTED_TYPE_DECL_H

#include "be_visitor_decl.h"

class TAO_OutStream;

/**
 * @class be_visitor_any_extracted_type_decl
 *
 * @brief be_visitor_any_extracted_type_decl
 *
 * Contains overloaded methods that generate declarations of
 * CORBA typenames for Any extraction
 */
class be_visitor_any_extracted_type_decl : public be_visitor_decl
{
public:
  be_visitor_any_extracted_type_decl (be_visitor_context *ctx);
  virtual ~be_visitor_any_extracted_type_decl ();

  virtual int visit_array (be_array *);
  virtual int visit_component (be_component *);
  virtual int visit_enum (be_enum *);
  virtual int visit_eventtype (be_eventtype *);
  virtual int visit_home (be_home *);
  virtual int visit_interface (be_interface *);
  virtual int visit_predefined_type (be_predefined_type *);
  virtual int visit_sequence (be_sequence *);
  virtual int visit_string (be_string *);
  virtual int visit_structure (be_structure *);
  virtual int visit_typedef (be_typedef *);
  virtual int visit_union (be_union *);
  virtual int visit_valuebox (be_valuebox *);
  virtual int visit_valuetype (be_valuetype *);

protected:
  const char * var_name_;
  const char * tmp_name_;
};

#endif /* BE_VISITOR_ANY_EXTRACTED_TYPE_DECL_H */
